@@ -10,17 +10,12 @@
 #![deny(unreachable_patterns)]
 #![feature(alloc_layout_extra)]
 #![feature(allocator_api)]
-#![feature(asm)]
-#![feature(const_fn_fn_ptr_basics)]
-#![feature(const_fn_trait_bound)]
 #![feature(const_mut_refs)]
 #![feature(const_ptr_is_null)]
 #![feature(const_ptr_offset_from)]
 #![cfg_attr(not(debug_assertions), feature(const_unreachable_unchecked))]
 #![feature(core_intrinsics)]
 #![feature(extend_one)]
-#![feature(llvm_asm)]
-#![feature(maybe_uninit_extra)]
 #![feature(maybe_uninit_slice)]
 #![feature(maybe_uninit_uninit_array)]
 #![feature(slice_index_methods)]
